TimeUtils class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
convertTimeStampToString(
String time) → String -
dateToString(
DateTime date, {List< String> ? formats}) → String -
dateToStringTime(
DateTime date) → String -
formatDateAsDay(
DateTime? tm) → String -
formatDateAsDayWithRemoveToday(
DateTime date) → String -
formatDateAsTimeAndDay(
DateTime? date) → String -
formatTime(
DateTime dateTime) → String -
getDateTimeFromServerTimeStamp(
Timestamp serverTimestamp) → DateTime? -
getDelayInDays(
{required DateTime startAt}) → int -
parseStringToDateAsTimeAndDay(
String? dateString) → String -
stringToDateTime(
String dateString) → DateTime -
timeAgo(
DateTime dateTime) → String