DateUtilsDateFormatImpl class

Inheritance
Implementers

Constructors

DateUtilsDateFormatImpl()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

convertDateToString(DateTime date, {List<String>? formats}) String
override
convertDateToStringTime(DateTime date) String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited