TimeStampUtilsImpl class
- Inheritance
-
- Object
- IDateUtils
- DateUtilsDateFormatImpl
- FormatDateUtilsDateFormatImpl
- TimeStampUtilsImpl
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
convertDateTimeToTimeStamp(
Timestamp timestamp) → DateTime? -
override
-
convertDateToString(
DateTime date, {List< String> ? formats}) → String -
inherited
-
convertDateToStringTime(
DateTime date) → String -
inherited
-
convertTimeStampToString(
String time) → String -
override
-
formatDateAsDayWeekMonth(
DateTime? tm) → String -
inherited
-
formatDateAsTimeAndDay(
DateTime? date) → String -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited